<?php

class RecursoController extends BaseController{

     public function muestraRecurso($id){

          $recurso=Recurso::find($id);
          $filename=$recurso->nombre;
          $datas=stream_get_contents($recurso->datas);
          $content="Content-type: ".$recurso->mime;
          $compressType=array("application/x-gzip","application/x-compressed","multipart/x-gzip",
               "application/x-tar","application/x-zip-compressed","application/zip","multipart/x-zip");

          if(in_array($recurso->mime, $compressType)){
               header($content);
               header('Content-Disposition: attachment; filename="'.$filename.'"');
               echo base64_decode($datas);
          }
          else{

          header($content);
          echo base64_decode($datas);
          }

     }


    /*Devuleve la vista del recurso seleccionado del menu del alumno*/
    public function show($tipo){
        $recursos = Recurso::where('tipo', $tipo)->orderBy('created_at', 'DESC')->get();
        $tipoView = [
            'lectura' => 'fa-book',
            'video' => 'fa-youtube-play',
            'enlace' => 'fa-external-link',
            'imagen' => 'fa-image',
            'otros' => 'fa-file-code-o'
        ];

        return View::make('pages.recurso', compact('recursos', 'tipo', 'tipoView'));
    }

    /*Visualiza un video*/
    public function showVideo($id){
        $video = Recurso::find($id);
        $videoKey = substr($video->url, 32, 11);
        return View::make('pages.showVideo', compact('video', 'videoKey'));

    }

    /*Subir recurso de tipo archivos: lectura, imagen, otros*/
    public function uploadFileSt($tipo){
        if(Input::hasFile('file')){

            $rules = [
                'descripcion' => 'required|min:5'
            ];

            $descripcion = Input::get('descripcion');

            $fields = [
                'descripcion' => $descripcion
            ];

            $validator = Validator::make($fields, $rules);

            if($validator->fails()){
                $msg='Error de validacion';
                return Redirect::back()->withErrors($validator);
            }

            $file = Input::file('file');
            $fileStream = base64_encode(file_get_contents($file->getRealPath()));
            $database = [
                'id_alumno' => Auth::user()->id_alumno,
                'nombre' => $file->getClientOriginalName(),
                'tipo' => $tipo,
                'datas' => $fileStream,
                'mime' => $file->getMimeType(),
                'descripcion' => $fields['descripcion'],
                'votos' => ''
            ];

            Recurso::create($database);

            $msg = "<div class='alert alert-success'> <b>Archivo subido!</b> </div>";

            return Redirect::back()->with('message', $msg);

        }
        else{
            $msg = "<div class='alert alert-danger'><b>No has seleccionado un archivo.</b></div>";
            return Redirect::back()->with('message', $msg);
        }
    }

    /*Compartir enlace: videos y enlace*/
    public function shareLinkSt($tipo){

        $rules = [
            'nombre' => 'required|min:3',
            'url' => 'required|url',
            'descripcion' => 'required|min:5'
        ];

        $fields = Input::all();

        $validator = Validator::make($fields, $rules);

        if($validator->fails()){
            return Redirect::back()->withErrors($validator);
        }

        $database = [
            'id_alumno' => Auth::user()->id_alumno,
            'nombre' => $fields['nombre'],
            'tipo' => $tipo,
            'url' => $fields['url'],
            'descripcion' => $fields['descripcion'],
            'votos' => ''
        ];

        Recurso::create($database);

        $msg = "<div class='alert alert-success'> <b>Enlace compartido!</b> </div>";

        return Redirect::back()->with('message', $msg);

    }

    /*Votar un recurso mediante ajax*/
    public function voteResource(){
        $idAlumno = Input::get('idAlumno');
        $idRecurso = (int)Input::get('idRecurso');

        $recurso = Recurso::find($idRecurso);
        $recurso->votos .= "-$idAlumno";
        $recurso->num_votos += 1;
        $recurso->save();



        return Response::json(['success' => 1]);
    }

    /*Vista de la lista de recursos*/
    public function listaRecursos(){
        $recursos = Recurso::whereNotNull('id_alumno')->orderBy('num_votos', 'DESC')->get();
        $alumnos = Alumno::lists('nombre', 'id_alumno');
        $paternos = Alumno::lists('apellido_pat', 'id_alumno');

        return View::make('pages.listaRecursos', compact('recursos', 'alumnos', 'paternos'));
    }
}


?>
